@@ -1,4 +1,4 @@
-/* $Id: init.c,v 1.33 2004/10/10 17:21:57 bdejean Exp $ */
+/* $Id: init.c,v 1.35 2005/04/27 14:50:24 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -22,7 +22,9 @@
 */
 
 #include <glibtop.h>
+#include <glibtop/error.h>
 #include <glibtop/sysdeps.h>
+#include <glibtop/open.h>
 #include <glibtop/parameter.h>
 
 #ifndef DEFAULT_PORT
