@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: uptime.c,v 1.10 2004/10/11 18:01:25 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -29,31 +27,29 @@
 #include <time.h>
 
 static const unsigned long _glibtop_sysdeps_uptime =
-(1L << GLIBTOP_UPTIME_UPTIME) + (1L <<GLIBTOP_UPTIME_BOOT_TIME);
+(1L <<GLIBTOP_UPTIME_BOOT_TIME)
+| (1L << GLIBTOP_UPTIME_UPTIME);
 
 /* Init function. */
 
-int
+void
 glibtop_init_uptime_s (glibtop *server)
 {
-    server->sysdeps.uptime = _glibtop_sysdeps_uptime;
-
-    return 0;
+	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
 }
 
 /* Provides uptime and idle time. */
 
-int
+void
 glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
 {
-    memset (buf, 0, sizeof (glibtop_uptime));
+	memset (buf, 0, sizeof (glibtop_uptime));
 
-    if(!(server->_priv->machine.boot))
-	return -GLIBTOP_ERROR_INCOMPATIBLE_KERNEL;
-    buf->boot_time = server->_priv->machine.boot;
-    buf->uptime = time(NULL) - server->_priv->machine.boot;
+	if(!(server->machine.boot))
+	    return;
 
-    buf->flags = _glibtop_sysdeps_uptime;
+	buf->boot_time = server->machine.boot;
+	buf->uptime = time(NULL) - server->machine.boot;
 
-    return 0;
+	buf->flags = _glibtop_sysdeps_uptime;
 }
